==> tin-1.00.tar.gz: tin-1.00/screen.c <==
/*
 *  Project   : tin - a visual threaded usenet newsreader
 *  Module    : screen.c
 *  Author    : R.Skrenta / I.Lea
 *  Created   : 01-04-91
 *  Updated   : 10-08-91
 *  Release   : 1.0
 *  Notes     :
 *  Copyright : (c) Copyright 1991 by Rich Skrenta & Iain Lea
 *	            You may  freely  copy or  redistribute  this software,
 *              so  long as there is no profit made from its use, sale
 *              trade or  reproduction.  You may not change this copy-
 *              right notice, and it must be included in any copy made
 */

#include	"tin.h"

extern int errno;

char msg[LEN+1];
struct screen_t *screen;


void info_message (msg)
	char *msg;
{
	clear_message();	  /* Clear any old messages hanging around */
	center_line(LINES, msg);  /* center the message at screen bottom  */
	MoveCursor(LINES, 0);
}


void wait_message (msg)
	char *msg;
{
	clear_message();	  /* Clear any old messages hanging around */
	printf (msg);
	fflush (stdout);
}


void error_message (template, msg)
	char *template;
	char *msg;
{
	errno = 0;

	if (! update) {
		clear_message();	  /* Clear any old messages hanging around */
	}
	fprintf (stderr, template, msg);
	fflush (stderr);

	/*	perror (""); */

	if (! update) {
		MoveCursor(LINES, 0);
	}
	sleep (1);
}


void clear_message ()
{
	MoveCursor(LINES, 0);
	CleartoEOLN();
}


void center_line (line, str)
	int line;
	char *str;
{
	int pos;

	pos = (COLS - (int) strlen (str)) / 2;
	MoveCursor (line, pos);
	printf ("%s", str);
	fflush (stdout);
}


void draw_arrow (line)
	int line;
{
	MoveCursor (line, 0);

	if (draw_arrow_mark) {
		printf ("->");
	} else {
		StartInverse ();
		printf ("%s", screen[line-INDEX_TOP].col);
		EndInverse ();
	}

	fflush (stdout);
	MoveCursor (LINES, 0);
}


void erase_arrow (line)
	int line;
{
	MoveCursor (line, 0);

	if (draw_arrow_mark) {
		printf ("  ");
	} else {
		printf ("%s", screen[line-INDEX_TOP].col);
	}

	fflush (stdout);
}

==> tin-1.02.tar.gz: tin-1.02/screen.c <==
/*
 *  Project   : tin - a visual threaded usenet newsreader
 *  Module    : screen.c
 *  Author    : R.Skrenta / I.Lea
 *  Created   : 01-04-91
 *  Updated   : 08-09-91
 *  Release   : 1.0
 *  Notes     :
 *  Copyright : (c) Copyright 1991 by Rich Skrenta & Iain Lea
 *	            You may  freely  copy or  redistribute  this software,
 *              so  long as there is no profit made from its use, sale
 *              trade or  reproduction.  You may not change this copy-
 *              right notice, and it must be included in any copy made
 */

#include	"tin.h"

extern int errno;

char msg[LEN+1];
struct screen_t *screen;


void info_message (msg)
	char *msg;
{
	clear_message();	  /* Clear any old messages hanging around */
	center_line(LINES, FALSE, msg);  /* center the message at screen bottom  */
	MoveCursor(LINES, 0);
}


void wait_message (msg)
	char *msg;
{
	if (RawState ()) {
		clear_message();	  /* Clear any old messages hanging around */
	}
	printf ("%s", msg);
	fflush (stdout);
}


void error_message (template, msg)
	char *template;
	char *msg;
{
	errno = 0;

	if (update == FALSE && RawState ()) {
		clear_message ();	  /* Clear any old messages hanging around */
	}
	
	fprintf (stderr, template, msg);
	fflush (stderr);

	if (update == FALSE && RawState ()) {
		MoveCursor (LINES, 0);
		sleep (2);
	} else {
		fprintf (stderr, "\n");
		fflush (stderr);
	}
}


void clear_message ()
{
	MoveCursor(LINES, 0);
	CleartoEOLN();
}


void center_line (line, inverse, str)
	int line;
	int inverse;
	char *str;
{
	int pos;

	pos = (COLS - (int) strlen (str)) / 2;
	MoveCursor (line, pos);
	if (inverse) {
		StartInverse ();
	}
	printf ("%s", str);
	fflush (stdout);
	if (inverse) {
		EndInverse ();
	}
}


void draw_arrow (line)
	int line;
{
	MoveCursor (line, 0);

	if (draw_arrow_mark) {
		printf ("->");
		fflush (stdout);
	} else {
		StartInverse ();
		printf ("%s", screen[line-INDEX_TOP].col);
		fflush (stdout);
		EndInverse ();
	}
	MoveCursor (LINES, 0);
}


void erase_arrow (line)
	int line;
{
	MoveCursor (line, 0);

	if (draw_arrow_mark) {
		printf ("  ");
	} else {
		printf ("%s", screen[line-INDEX_TOP].col);
	}
	fflush (stdout);
}
